%define osstring %(source /etc/os-release; echo ${ID})
%bcond_without check
# https://github.com/slackhq/nebula
%global goipath github.com/slackhq/nebula
Version:        1.8.2
%global tag     %{version}

%gometa -f

%global common_description %{expand:
A scalable overlay networking tool with a focus on performance, simplicity and
security.}

Name:           nebula
Release:        1%{?dist}
Summary:        A scalable overlay networking tool with a focus on performance, simplicity and security
License:        MIT
URL:            %{gourl}
Source0:        %{name}-%{version}.tar.gz
Source1:        nebula.service
# In EL, we need to vendor libraries and generate a list
# of bundled provides. And as we only care about EL, we
# don't have if logic here.
#
# To make a vendored tar, run the following:
# $ tar xf nebula-VERSION.tar.gz
# $ pushd nebula-VERSION
# $ go mod vendor
# $ tar -cvJf ../nebula-1.8.2-vendor.tar.gz vendor/
# $ sed '/^#/d ; s/^/Provides: bundled(golang(/g ; s/$/))/g' \
#     vendor/modules.txt > ../nebula.provides
# $ popd
#
# There, now you have a vendored tarball and provides :)
Source2:        %{name}-vendor-%{version}.tar.gz
Source3:        %{name}.provides
# You need to list a custom bit of provides here for "bundled" - This can be
# achieved by taking the modules.txt file and doing some hacky work to generate
# it.
#
BuildRequires:  systemd-rpm-macros
BuildRequires:  compiler(go-compiler)
BuildRequires:  go-rpm-macros

# Bundled provides imported here
%include %{SOURCE3}

%description
%{common_description}

%gopkg

%prep
%autosetup -a 2
# Everything here is manual for EL
mkdir -p "%{_builddir}/src/github.com/slackhq/"
cp -r %{_builddir}/%{name}-%{version} %{_builddir}/src/github.com/slackhq/%{name}
mkdir -p %{_builddir}/%{name}-%{version}/_build/src/github.com/slackhq/nebula
mv %{_builddir}/src %{_builddir}/%{name}-%{version}/_build/src

%build
# Everything here is manual for EL
export LDFLAGS="-X main.Build=%{version}-%{osstring} $(LDFLAGS)"
export GOPATH="%{_builddir}/%{name}-%{version}/_build"
pushd $GOPATH/src/github.com/slackhq/nebula
go generate
popd
for cmd in cmd/* ; do
  %gobuild -o bin/$(basename $cmd) %{goipath}/$cmd
done

%install
%gopkginstall
# Binaries
install -m 0755 -vd                     %{buildroot}%{_bindir}
install -m 0755 -vp bin/*               %{buildroot}%{_bindir}/
# Configs (/etc)
install -m 0755 -vd                     %{buildroot}%{_sysconfdir}/%{name}
install -m 0640 -vp examples/config.yml %{buildroot}%{_sysconfdir}/%{name}
# Service file
install -m 0644 -vDp %{SOURCE1}         %{buildroot}%{_unitdir}/%{name}.service

%if %{with check}
%check
%gocheck
%endif

%post
%systemd_post nebula.service

%preun
%systemd_preun nebula.service

%postun
%systemd_postun_with_restart nebula.service

%files
%license LICENSE
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/config.yml
%doc examples AUTHORS README.md CHANGELOG.md
%{_bindir}/*
%{_unitdir}/%{name}.service

%gopkgfiles

%changelog
* Fri Mar 15 2024 Louis Abel <label@resf.org> - 1.8.2-1
- Package Nebula 1.8.2 for Rocky Linux
